@@ -2,7 +2,7 @@ g.analyse =  function(I,C,M,IMP,qlevels=c(),qwindow=c(0,24),quantiletype = 7,L5M
                       includedaycrit = 16,ilevels=c(),winhr=5,idloc=1,snloc=1,
                       mvpathreshold = c(),boutcriter=c(),mvpadur=c(1,5,10),selectdaysfile=c(),
                       window.summary.size=10,
-                      dayborder=0,mvpa.2014 = FALSE,closedbout=FALSE) {
+                      dayborder=0,bout.metric = 1,closedbout=FALSE,desiredtz=c()) {
   winhr = winhr[1]
   fname=I$filename
   averageday = IMP$averageday
@@ -97,11 +97,11 @@ g.analyse =  function(I,C,M,IMP,qlevels=c(),qwindow=c(0,24),quantiletype = 7,L5M
   timeline = seq(0,ceiling(nrow(metalong)/n_ws2_perday),by=1/n_ws2_perday)	
   timeline = timeline[1:nrow(metalong)]
   tooshort = 0
-  dmidn = g.detecmidnight(ND,time)
+  dmidn = g.detecmidnight(ND,time,desiredtz)
   firstmidnight=dmidn$firstmidnight;  firstmidnighti=dmidn$firstmidnighti
   lastmidnight=dmidn$lastmidnight;    lastmidnighti=dmidn$lastmidnighti
   midnights=dmidn$midnights;          midnightsi=dmidn$midnightsi
-  
+
   if (dayborder != 0) {
     midnightsi = ((midnightsi + (dayborder * (3600/ws2))) -1) + (1/(ws2/ws3)) #shift the definition of midnight if required
     # midnightsi = ((midnightsi + (dayborder * (3600/ws2))) -1) + 1 #shift the definition of midnight if required
@@ -145,7 +145,6 @@ g.analyse =  function(I,C,M,IMP,qlevels=c(),qwindow=c(0,24),quantiletype = 7,L5M
   LW = length(which(as.numeric(qcheck) != 1)) / (60/ws3) #number of minutes wear time between first and last midnights
   nfulldays = (lastmidnighti - firstmidnighti) / ((3600/ws2)*24)
   ndays = length(midnights) + 1 #ceiling(nfulldays + 2) # ceiling to cope with days with 23 hours
-  
   if (ndays != round(ndays)) { #day saving time causing trouble?
     cat("One day in this measurement is longer or shorter than 24 hours (probably related to day saving time)")
   }    
@@ -211,7 +210,9 @@ g.analyse =  function(I,C,M,IMP,qlevels=c(),qwindow=c(0,24),quantiletype = 7,L5M
       cat("measurement starts at midnight or there is no midnight")  #new 28-11-2012
     }
     endatmidnight = 0
-    if (lastmidnight == time[length(time)] ) {	#if measurement ends at midnight
+  
+
+    if (lastmidnight == time[length(time)] & nrow(M$metashort) < ((60/ws3) * 1440)) {	#if measurement ends at midnight
       ndays = ndays - 1
       endatmidnight = 1
       cat("measurement ends at midnight or there is no midnight")
@@ -267,6 +268,9 @@ g.analyse =  function(I,C,M,IMP,qlevels=c(),qwindow=c(0,24),quantiletype = 7,L5M
           qqq2 = (midnightsi[di]*(ws2/ws3))-1
         }
       }
+     
+      
+      if (qqq2 > nrow(metashort)) qqq2 = nrow(metashort)
       vari = as.matrix(metashort[qqq1:qqq2,])
       val = qcheck[qqq1:qqq2]
       #--------------------------------
@@ -289,11 +293,14 @@ g.analyse =  function(I,C,M,IMP,qlevels=c(),qwindow=c(0,24),quantiletype = 7,L5M
       ds_names[fi] = "id";      fi = fi + 1
       daysummary[di,fi] = fname
       ds_names[fi] = "filename";  fi = fi + 1
-      if (length(selectdaysfile) > 0) {
-        calenderdate = unlist(strsplit(as.character(vari[min(c(10,nrow(vari))),1])," "))[1] #adjusted for millenium cohort
-      } else {
-        calenderdate = unlist(strsplit(as.character(vari[1,1])," "))[1]
-      }
+      # if (length(selectdaysfile) > 0) {
+      #   calenderdate = unlist(strsplit(as.character(vari[min(c(10,nrow(vari))),1])," "))[1] #adjusted for millenium cohort
+      #   print(calenderdate)
+      #   print(unlist(strsplit(as.character(vari[1,1])," "))[1])
+      #   # print(unlist(strsplit(as.character(vari[min(c(nrow(vari))),1])," "))[1])
+      # } else {
+      calenderdate = unlist(strsplit(as.character(vari[1,1])," "))[1]
+      # }
       daysummary[di,fi] = calenderdate               
       daysummary[di,(fi+1)] =BL
       daysummary[di,(fi+2)] = nvalidhours
@@ -335,11 +342,11 @@ g.analyse =  function(I,C,M,IMP,qlevels=c(),qwindow=c(0,24),quantiletype = 7,L5M
             windowsummary[gikb+gik,((metrici-2)*Nfeatures)+6] = mean(as.numeric(vari[bbb1:bbb2,metrici]))
             windowsummary[gikb+gik,((metrici-2)*Nfeatures)+7] = sd(as.numeric(vari[bbb1:bbb2,metrici]))
             if (nrow(vari) > 10 & (bbb2 - bbb1) > 10) {
-              windowsummary[gikb+gik,((metrici-2)*Nfeatures)+8] = quantile(as.numeric(vari[bbb1:bbb2,metrici]),probs=0.05)
-              windowsummary[gikb+gik,((metrici-2)*Nfeatures)+9] = quantile(as.numeric(vari[bbb1:bbb2,metrici]),probs=0.25)
-              windowsummary[gikb+gik,((metrici-2)*Nfeatures)+10] = quantile(as.numeric(vari[bbb1:bbb2,metrici]),probs=0.5)
-              windowsummary[gikb+gik,((metrici-2)*Nfeatures)+11] = quantile(as.numeric(vari[bbb1:bbb2,metrici]),probs=0.75)
-              windowsummary[gikb+gik,((metrici-2)*Nfeatures)+12] = quantile(as.numeric(vari[bbb1:bbb2,metrici]),probs=0.95)
+              windowsummary[gikb+gik,((metrici-2)*Nfeatures)+8] = quantile(as.numeric(vari[bbb1:bbb2,metrici]),probs=0.05,na.rm =TRUE)
+              windowsummary[gikb+gik,((metrici-2)*Nfeatures)+9] = quantile(as.numeric(vari[bbb1:bbb2,metrici]),probs=0.25,na.rm =TRUE)
+              windowsummary[gikb+gik,((metrici-2)*Nfeatures)+10] = quantile(as.numeric(vari[bbb1:bbb2,metrici]),probs=0.5,na.rm =TRUE)
+              windowsummary[gikb+gik,((metrici-2)*Nfeatures)+11] = quantile(as.numeric(vari[bbb1:bbb2,metrici]),probs=0.75,na.rm =TRUE)
+              windowsummary[gikb+gik,((metrici-2)*Nfeatures)+12] = quantile(as.numeric(vari[bbb1:bbb2,metrici]),probs=0.95,na.rm =TRUE)
             } else {
               windowsummary[gikb+gik,(((metrici-2)*Nfeatures)+8):(((metrici-2)*Nfeatures)+12)] = NA
             }
@@ -450,112 +457,59 @@ g.analyse =  function(I,C,M,IMP,qlevels=c(),qwindow=c(0,24),quantiletype = 7,L5M
                   select = seq(1,length(varnum2),by=300/ws3)
                   varnum3 = diff(varnum2[round(select)]) / abs(diff(round(select)))
                   mvpa[3] = length(which(varnum3*1000 >= mvpathreshold[mvpai])) * 5 #time spent MVPA in minutes
-                  if (mvpa.2014 == FALSE) { # MVPA bout calculation like in the 2014 papers
+                  if (bout.metric == 1) { # MVPA bout calculation like in the 2014 papers
                     # METHOD 4: time spent above threshold
-                    boutdur2 = mvpadur[1] * (60/ws3) # per minute
+                    boutduration = mvpadur[1] * (60/ws3) # per minute
                     rr1 = matrix(0,length(varnum),1)
                     p = which(varnum*1000 >= mvpathreshold[mvpai]); rr1[p] = 1
-                    getboutout = g.getbout(rr=rr1,boutdur2=boutdur2,boutcriter=boutcriter,p=p,closedbout=closedbout)
+                    getboutout = g.getbout(x=rr1,boutduration=boutduration,boutcriter=boutcriter,closedbout=closedbout,
+                                           bout.metric=bout.metric,ws3=ws3)
                     mvpa[4] = length(which(getboutout$rr == 1))   / (60/ws3) #time spent MVPA in minutes
                     # METHOD 5: time spent above threshold 5 minutes
-                    boutdur2 = mvpadur[2] * (60/ws3) #per five minutes
+                    boutduration = mvpadur[2] * (60/ws3) #per five minutes
                     rr1 = matrix(0,length(varnum),1)
                     p = which(varnum*1000 >= mvpathreshold[mvpai]); rr1[p] = 1
-                    getboutout = g.getbout(rr=rr1,boutdur2=boutdur2,boutcriter=boutcriter,p=p,closedbout=closedbout)
+                    getboutout = g.getbout(x=rr1,boutduration=boutduration,boutcriter=boutcriter,closedbout=closedbout,
+                                           bout.metric=bout.metric,ws3=ws3)
                     mvpa[5] = length(which(getboutout$rr == 1))   / (60/ws3) #time spent MVPA in minutes
                     # METHOD 6: time spent above threshold 10 minutes
-                    boutdur2 = mvpadur[3] * (60/ws3) # per ten minutes
+                    boutduration = mvpadur[3] * (60/ws3) # per ten minutes
                     rr1 = matrix(0,length(varnum),1)
                     p = which(varnum*1000 >= mvpathreshold[mvpai]); rr1[p] = 1
-                    getboutout = g.getbout(rr=rr1,boutdur2=boutdur2,boutcriter=boutcriter,p=p,closedbout=closedbout)
+                    getboutout = g.getbout(x=rr1,boutduration=boutduration,boutcriter=boutcriter,closedbout=closedbout,
+                                           bout.metric=bout.metric,ws3=ws3)
                     mvpa[6] = length(which(getboutout$rr == 1))   / (60/ws3) #time spent MVPA in minutes
                     if (length(which(varnum*1000 >= mvpathreshold[mvpai])) < 0 & length(varnum) < 100) {
                       mvpa[1:6] = 0
                     }
                     
-                  } else { # updated version
+                  } else if (bout.metric == 2) { # updated version
                     # cat("\nWARNING: MVPA Bout defintion has been updated, please see package manual for more information")
                     # cat("\nincluding instructions on how to continue using the old defintion\n")
                     # METHOD 4: time spent above threshold
-                    boutdur2 = 60/ws3 # per minute
+                    boutduration = 60/ws3 # per minute
                     rr1 = matrix(0,length(varnum),1)
-                    p = which(varnum*1000 >= mvpathreshold[mvpai])
-                    rr1[p] = 1
-                    rr1t = rr1
-                    jmvpa = 1
-                    while(jmvpa <= length(p)) {
-                      endi = p[jmvpa]+boutdur2
-                      if (endi <= length(rr1)) { #does bout fall without measurement?
-                        lengthbout = sum(rr1[p[jmvpa]:endi])
-                        if (lengthbout > (boutdur2*boutcriter)) {
-                          rr1t[p[jmvpa]:endi] = 2 #remember that this was a bout in r1t
-                        } else {
-                          rr1[p[jmvpa]] = 0
-                        }    	
-                      } else { #bout does not fall within measurement
-                        if (length(p) > 1 & jmvpa > 2) {
-                          rr1[p[jmvpa]] = rr1[p[jmvpa-1]]
-                        }				
-                      }
-                      jmvpa = jmvpa + 1
-                    }
-                    rr1[which(rr1t == 2)] = 1
-                    mvpa[4] = length(which(rr1 == 1))   / (60/ws3) #time spent MVPA in minutes
+                    p = which(varnum*1000 >= mvpathreshold[mvpai]); rr1[p] = 1
+                    getboutout = g.getbout(x=rr1,boutduration=boutduration,boutcriter=boutcriter,closedbout=closedbout,
+                                           bout.metric=bout.metric)
+                    mvpa[4] = length(which(getboutout$rr == 1))   / (60/ws3) #time spent MVPA in minutes
                     # METHOD 5: time spent above threshold 5 minutes
-                    boutdur2 = 5 * (60/ws3)
+                    boutduration = 5 * (60/ws3)
                     rr1 = matrix(0,length(varnum),1)
-                    p = which(varnum*1000 >= mvpathreshold[mvpai])
-                    rr1[p] = 1
-                    rr1t = rr1
-                    jmvpa = 1
-                    while(jmvpa <= length(p)) {
-                      endi = p[jmvpa]+boutdur2
-                      if (endi <= length(rr1)) { #does bout fall without measurement?
-                        lengthbout = sum(rr1[p[jmvpa]:endi])
-                        if (lengthbout > (boutdur2*boutcriter)) { #0.9 => 90% of the bout needs to meet the criteria
-                          rr1t[p[jmvpa]:endi] = 2 #remember that this was a bout in r1t
-                        } else {
-                          rr1[p[jmvpa]] = 0
-                        }    	
-                      } else { #bout does not fall within measurement
-                        if (length(p) > 1 & jmvpa > 2) {
-                          rr1[p[jmvpa]] = rr1[p[jmvpa-1]]
-                        }				
-                      }
-                      jmvpa = jmvpa + 1
-                    }
-                    rr1[which(rr1t == 2)] = 1
-                    mvpa[5] = length(which(rr1 == 1))   / (60/ws3) #time spent MVPA in minutes
+                    p = which(varnum*1000 >= mvpathreshold[mvpai]); rr1[p] = 1
+                    getboutout = g.getbout(x=rr1,boutduration=boutduration,boutcriter=boutcriter,closedbout=closedbout,
+                                           bout.metric=bout.metric)
+                    mvpa[5] = length(which(getboutout$rr1 == 1))   / (60/ws3) #time spent MVPA in minutes
                     # METHOD 6: time spent above threshold 10 minutes
-                    boutdur2 = 10 * (60/ws3) 
+                    boutduration = 10 * (60/ws3) 
                     rr1 = matrix(0,length(varnum),1)
-                    p = which(varnum*1000 >= mvpathreshold[mvpai])
-                    rr1[p] = 1
-                    rr1t = rr1
-                    jmvpa = 1
-                    while(jmvpa <= length(p)) {
-                      endi = p[jmvpa]+boutdur2
-                      if (endi <= length(rr1)) { #does bout fall without measurement?
-                        lengthbout = sum(rr1[p[jmvpa]:endi])
-                        if (lengthbout > (boutdur2*boutcriter)) { #0.9 => 90% of the bout needs to meet the criteria
-                          rr1t[p[jmvpa]:endi] = 2 #remember that this was a bout in r1t
-                        } else {
-                          rr1[p[jmvpa]] = 0
-                        }      
-                      } else { #bout does not fall within measurement
-                        if (length(p) > 1 & jmvpa > 2) {
-                          rr1[p[jmvpa]] = rr1[p[jmvpa-1]]
-                        }				
-                      }
-                      jmvpa = jmvpa + 1
-                    }
-                    rr1[which(rr1t == 2)] = 1
-                    mvpa[6] = length(which(rr1 == 1))   / (60/ws3) #time spent MVPA in minutes
+                    p = which(varnum*1000 >= mvpathreshold[mvpai]); rr1[p] = 1
+                    getboutout = g.getbout(x=rr1,boutduration=boutduration,boutcriter=boutcriter,closedbout=closedbout,
+                                           bout.metric=bout.metric)
+                    mvpa[6] = length(which(getboutout$rr1 == 1))   / (60/ws3) #time spent MVPA in minutes
                   }
                   
                   
-                  
-                  
                   if (length(which(is.nan(mvpa) == TRUE)) > 0) mvpa[which(is.nan(mvpa) == TRUE)] = 0
                   mvpanames[,mvpai] = c( paste("MVPA_E",ws3,"S_T",mvpathreshold[mvpai],sep=""),
                                          paste("MVPA_E1M_T",mvpathreshold[mvpai],sep=""),
